#!/bin/sh
# Retries all permanently FAILED PERFORMANCE batches
. /opt/zenoss_analytics/bin/analytics_fix/set_analytics_env.sh

batches_exist=$($RUNZENDSQUERY "
   select count(1) from meta_batch mb
      join meta_extractor me on mb.extractor_key = me.extractor_key
      and me.extractor_type = 'PERFORMANCE'
   where
      mb.batch_state = 'FAILED'
   and mb.batch_attempts = mb.batch_max_attempts;
")

if [ ${batches_exist} -eq 0 ]
then
   echo "There are no permanently FAILED PERFORMANCE batches"
   exit 2
fi

echo "There are" ${batches_exist} "permanently FAILED PERFORMANCE batches"
while true
do
  read -p "OK to retry them all once? (y/n) " yn
  case  $yn
  in
    [Yy]* ) break;;
    [Nn]* ) echo "Bailing out"; exit;;
    * )     echo "Please answer yes or no.";;
  esac
done

echo "marking" ${batches_exist} "batches for retry..."

$RUNZENDSQUERYCOLS "
  update meta_batch set batch_attempts=batch_max_attempts-1
  where batch_state = 'FAILED' and batch_attempts=batch_max_attempts
  and extractor_key in
     (select extractor_key from meta_extractor where extractor_type = 'PERFORMANCE');
"

batches_exist=$($RUNZENDSQUERY "
   select count(1) from meta_batch mb
      join meta_extractor me on mb.extractor_key = me.extractor_key
      and me.extractor_type = 'PERFORMANCE'
   where
      mb.batch_state = 'FAILED'
   and mb.batch_attempts = mb.batch_max_attempts;
")

if [ ${batches_exist} -ne 0 ]
then
   echo "Failed! There are still" ${batches_exist} "permanently FAILED PERFORMANCE batches"
   exit 2
fi

echo "Success, all permanently FAILED PERFORMANCE batches marked for retry!"
